from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.consts import ANY_VALUE


class OSSBucketVersioning(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure OSS bucket has versioning enabled"
        id = "CKV_ALI_10"
        supported_resources = ['alicloud_oss_bucket']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'versioning/[0]/status'

    def get_expected_value(self):
        return 'Enabled'


check = OSSBucketVersioning()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class EKSPublicAccessCIDR(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Amazon EKS public endpoint not accessible to 0.0.0.0/0"
        id = "CKV_AWS_38"
        supported_resources = ['aws_eks_cluster']
        categories = [CheckCategories.KUBERNETES]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for public_access_cidrs at aws_eks_cluster:
            https://www.terraform.io/docs/providers/aws/r/eks_cluster.html
        :param conf: aws_eks_cluster configuration
        :return: <CheckResult>
        """
        self.evaluated_keys = ['vpc_config']
        if "vpc_config" in conf.keys():
            if "endpoint_public_access" in conf["vpc_config"][0] and not conf["vpc_config"][0]["endpoint_public_access"][0]:
                self.evaluated_keys = ['vpc_config/[0]/endpoint_public_access']
                return CheckResult.PASSED
            elif "public_access_cidrs" in conf["vpc_config"][0]:
                self.evaluated_keys = ['vpc_config/[0]/public_access_cidrs']
                cidrs = conf["vpc_config"][0]["public_access_cidrs"]
                if cidrs and len(cidrs[0]) and "0.0.0.0/0" not in cidrs[0]:
                    return CheckResult.PASSED
            return CheckResult.FAILED
        return CheckResult.UNKNOWN


check = EKSPublicAccessCIDR()



import json
from typing import Dict, Any

from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class IAMRoleAllowsPublicAssume(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure IAM role allows only specific services or principals to assume it"
        id = "CKV_AWS_60"
        supported_resources = ("AWS::IAM::Role",)
        categories = (CheckCategories.IAM,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[str, Any]) -> CheckResult:
        self.evaluated_keys = ["Properties/AssumeRolePolicyDocument/Statement"]
        properties = conf.get("Properties")
        if isinstance(properties, dict):
            assume_role_policy_doc = properties.get("AssumeRolePolicyDocument")
            if isinstance(assume_role_policy_doc, str):
                assume_role_policy_doc = json.loads(assume_role_policy_doc)
            if isinstance(assume_role_policy_doc, dict) and assume_role_policy_doc.get("Statement"):
                statements = assume_role_policy_doc["Statement"]
                if isinstance(statements, list):
                    for statement_index, statement in enumerate(statements):
                        if statement.get("Effect") == "Deny":
                            continue
                        principal = statement.get("Principal")
                        if isinstance(principal, dict):
                            aws_principals = principal.get("AWS")
                            if aws_principals == "*":
                                self.evaluated_keys = [
                                    f"Properties/AssumeRolePolicyDocument/Statement/[{statement_index}]/Principal/AWS"
                                ]
                                return CheckResult.FAILED
                            if isinstance(aws_principals, list):
                                for principal_index, principal in enumerate(aws_principals):
                                    if principal == "*":
                                        self.evaluated_keys = [
                                            f"Properties/AssumeRolePolicyDocument/Statement/[{statement_index}]/Principal/[{principal_index}]/AWS"
                                        ]
                                        return CheckResult.FAILED
        return CheckResult.PASSED


check = IAMRoleAllowsPublicAssume()



from typing import Union, List, Any
from checkov.common.graph.graph_builder.graph_components.block_types import BlockType
from abc import ABC, abstractmethod


class VertexReference(ABC):
    def __init__(self, block_type: Union[str, BlockType], sub_parts: List[str], origin_value: str) -> None:
        self.block_type: BlockType = self.block_type_str_to_enum(block_type) if isinstance(block_type, str) else block_type
        self.sub_parts = sub_parts
        self.origin_value = origin_value

    def __eq__(self, other: Any) -> bool:
        if not isinstance(other, VertexReference):
            return False
        return (
            self.block_type == other.block_type
            and self.sub_parts == other.sub_parts
            and self.origin_value == other.origin_value
        )

    def __str__(self) -> str:
        return f"{self.block_type} sub_parts = {self.sub_parts}, origin = {self.origin_value}"

    @staticmethod
    @abstractmethod
    def block_type_str_to_enum(block_type_str: str):
        pass



import logging
from abc import abstractmethod

import docker


class ImageReferencer:

    @abstractmethod
    def is_workflow_file(self, file_path: str) -> bool:
        """

        :param file_path: path of file to validate if it is a file that contains might images (example: CI workflow file)
        :return: True if contains images

        """
        return False

    @abstractmethod
    def get_images(self, file_path: str) -> [str]:
        """
        Get container images mentioned in a file
        :param file_path: File to be inspected
        :return: List of container image short ids mentioned in the file.
        """
        return []

    def pull_image(self, image_name: str) -> str:
        """

        :param image_name: name of the image to be pulled locally using a "docker pull X" command
        :return: short image id sha that is pulled locally. In case pull has failed None will be returned.
        """
        try:
            logging.info("Pulling docker image {}", image_name)
            client = docker.from_env()
            image = client.images.pull(image_name)
            return image.short_id
        except Exception:
            logging.debug(f"failed to pull docker image={image_name}", exc_info=True)
            return ""



from __future__ import annotations

from typing import Any

from typing_extensions import Literal

from checkov.common.graph.graph_builder.graph_components.blocks import Block


class BicepBlock(Block):
    def __init__(
        self,
        name: str,
        config: dict[str, Any],
        path: str,
        block_type: str,
        attributes: dict[str, Any],
        id: str = "",
    ) -> None:
        super().__init__(name, config, path, block_type, attributes, id, "Bicep")



from checkov.terraform.module_loading.loaders.git_loader import GenericGitLoader


class BitbucketLoader(GenericGitLoader):
    def _is_matching_loader(self) -> bool:
        # https://www.terraform.io/docs/modules/sources.html#bitbucket
        if self.module_source.startswith("bitbucket.org"):
            self.module_source = f"git::https://{self.module_source}"
            return True
        return False


loader = BitbucketLoader()



import os
from typing import Union, Dict, Any, List, Optional, Set

from checkov.common.graph.graph_builder.graph_components.blocks import Block
from checkov.common.graph.graph_builder.variable_rendering.breadcrumb_metadata import BreadcrumbMetadata
from checkov.common.util.consts import RESOLVED_MODULE_ENTRY_NAME
from checkov.terraform.graph_builder.graph_components.block_types import BlockType
from checkov.terraform.graph_builder.utils import remove_module_dependency_in_path


class TerraformBlock(Block):
    def __init__(self, name: str, config: Dict[str, Any], path: str, block_type: BlockType, attributes: Dict[str, Any],
                 id: str = "", source: str = "") -> None:
        """
            :param name: unique name given to the terraform block, for example: 'aws_vpc.example_name'
            :param config: the section in tf_definitions that belong to this block
            :param path: the file location of the block
            :param block_type: BlockType
            :param attributes: dictionary of the block's original attributes in the terraform file
        """
        super(TerraformBlock, self).__init__(name, config, path, block_type, attributes, id, source)
        self.module_dependency = ""
        self.module_dependency_num = ""
        if path:
            self.path, module_dependency, num = remove_module_dependency_in_path(path)
            self.path = os.path.realpath(self.path)
            if module_dependency:
                self.module_dependency = module_dependency
                self.module_dependency_num = num
        if attributes.get(RESOLVED_MODULE_ENTRY_NAME):
            del attributes[RESOLVED_MODULE_ENTRY_NAME]
        self.attributes = attributes
        self.module_connections: Dict[str, List[int]] = {}
        self.source_module: Set[int] = set()

    def add_module_connection(self, attribute_key: str, vertex_id: int) -> None:
        self.module_connections.setdefault(attribute_key, []).append(vertex_id)

    def find_attribute(self, attribute: Optional[Union[str, List[str]]]) -> Optional[str]:
        """
        :param attribute: key to search in self.attributes
        The function searches for  attribute in self.attribute. It might not exist if the block is variable or output,
        or its search path might be different if its a resource.
        :return: the actual attribute key or None
        """
        if not attribute:
            return None

        if self.attributes.get(attribute[0]):
            return attribute[0]

        if self.block_type == BlockType.VARIABLE:
            return "default" if self.attributes.get("default") else None

        if self.block_type == BlockType.OUTPUT:
            return "value" if self.attributes.get("value") else None

        if self.block_type == BlockType.RESOURCE and len(attribute) > 1:
            # handle cases where attribute_at_dest == ['aws_s3_bucket.template_bucket', 'acl']
            if self.name == attribute[0] and self.attributes.get(attribute[1]):
                return attribute[1]

        return None

    def update_attribute(
        self, attribute_key: str, attribute_value: Any, change_origin_id: int,
            previous_breadcrumbs: List[BreadcrumbMetadata], attribute_at_dest: str
    ) -> None:
        self.update_inner_attribute(attribute_key, self.attributes, attribute_value)
        super().update_attribute(attribute_key, attribute_value, change_origin_id, previous_breadcrumbs, attribute_at_dest)

    def update_inner_attribute(
        self, attribute_key: str, nested_attributes: Union[List[Any], Dict[str, Any]], value_to_update: Any
    ) -> None:
        split_key = attribute_key.split(".")
        i = 1
        curr_key = ".".join(split_key[0:i])
        if isinstance(nested_attributes, list):
            if curr_key.isnumeric():
                curr_key_int = int(curr_key)
                if curr_key_int < len(nested_attributes):
                    if not isinstance(nested_attributes[curr_key_int], dict):
                        nested_attributes[curr_key_int] = value_to_update
                    else:
                        self.update_inner_attribute(
                            ".".join(split_key[i:]), nested_attributes[curr_key_int], value_to_update
                        )
            else:
                for inner in nested_attributes:
                    self.update_inner_attribute(curr_key, inner, value_to_update)
        elif isinstance(nested_attributes, dict):
            while curr_key not in nested_attributes and i <= len(split_key):
                i += 1
                curr_key = ".".join(split_key[0:i])
            if attribute_key in nested_attributes.keys():
                nested_attributes[attribute_key] = value_to_update
            if len(split_key) == 1 and len(curr_key) > 0:
                nested_attributes[curr_key] = value_to_update
            elif curr_key in nested_attributes.keys():
                self.update_inner_attribute(".".join(split_key[i:]), nested_attributes[curr_key], value_to_update)

    @classmethod
    def get_inner_attributes(
        cls,
        attribute_key: str,
        attribute_value: Union[str, List[str], Dict[str, Any]],
        strip_list: bool = True
    ) -> Dict[str, Any]:
        if strip_list and isinstance(attribute_value, list) and len(attribute_value) == 1:
            attribute_value = attribute_value[0]

        return super().get_inner_attributes(
            attribute_key=attribute_key,
            attribute_value=attribute_value,
        )



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class ACRAnonymousPullDisabled(BaseResourceCheck):
    def __init__(self):
        name = "Ensures that ACR disables anonymous pulling of images"
        id = "CKV_AZURE_138"
        supported_resources = ['azurerm_container_registry']
        categories = [CheckCategories.IAM]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        # anonymous_pull_enabled only applies to Standard and Premium skus, by default is set to false
        if ('sku' in conf.keys() and conf['sku'][0] in ["Standard", "Premium"] 
            and 'anonymous_pull_enabled' in conf.keys() and conf['anonymous_pull_enabled'][0]):
            return CheckResult.FAILED

        return CheckResult.PASSED


check = ACRAnonymousPullDisabled()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class AbsSecurityGroupUnrestrictedIngress(BaseResourceCheck):
    def __init__(self, check_id: str, port: int) -> None:
        name = f"Ensure no security groups rules allow ingress from 0.0.0.0/0 to port {port}"
        supported_resources = ['oci_core_network_security_group_security_rule']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=check_id, categories=categories, supported_resources=supported_resources)
        self.port = port

    def scan_resource_conf(self, conf):
        direction = conf.get('direction')
        source = conf.get('source')
        protocol = conf.get('protocol')
        tcp_options = conf.get('tcp_options')
        self.evaluated_keys = ["direction"]
        if direction and direction[0] != 'INGRESS':
            return CheckResult.UNKNOWN
        self.evaluated_keys.append("source")
        if source and source[0] != "0.0.0.0/0":
            return CheckResult.PASSED
        elif (tcp_options is None and (protocol[0] == 'all' or protocol[0] == '6')) \
                or tcp_options and self.scan_protocol_conf(tcp_options) is False:
            self.evaluated_keys.append("protocol")
            return CheckResult.FAILED
        return CheckResult.PASSED

    def scan_protocol_conf(self, protocol_name):
        """ scan tcp_options configuration"""
        max_port = protocol_name[0]['source_port_range'][0]['max'][0]
        min_port = protocol_name[0]['source_port_range'][0]['min'][0]
        if min_port <= self.port <= max_port:
            return False
        return True



from typing import List

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class APIManagementCertsEnforced(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Client Certificates are enforced for API management"
        id = "CKV_AZURE_152"
        supported_resources = ['azurerm_api_management']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if conf.get('sku_name'):
            if conf['sku_name'] == ["Consumption"]:
                if conf.get('client_certificate_enabled'):
                    if conf.get('client_certificate_enabled') == [True]:
                        return CheckResult.PASSED
                self.evaluated_keys = ['/client_certificate_enabled/']
                return CheckResult.FAILED
        return CheckResult.UNKNOWN


check = APIManagementCertsEnforced()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class MySQLTreatDetectionEnabled(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that My SQL server enables Threat detection policy"
        id = "CKV_AZURE_127"
        supported_resources = ['azurerm_mysql_server']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)


    def get_inspected_key(self):
        return "threat_detection_policy/[0]/enabled"


check = MySQLTreatDetectionEnabled()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.util.type_forcers import force_int


class PasswordPolicyLength(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure RAM password policy requires minimum length of 14 or greater"
        id = "CKV_ALI_13"
        supported_resources = ['alicloud_ram_account_password_policy']
        categories = [CheckCategories.IAM]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'minimum_password_length'

    def get_expected_value(self):
        return 14

    def scan_resource_conf(self, conf):
        """
            validates ram password policy
            https://registry.terraform.io/providers/aliyun/alicloud/latest/docs/resources/ram_account_password_policy
        :param conf: alicloud_ram_account_password_policy configuration
        :return: <CheckResult>
        """
        key = 'minimum_password_length'
        if key in conf.keys():
            length = conf[key][0]
            if self._is_variable_dependant(length):
                return CheckResult.UNKNOWN
            length = force_int(length)
            if not (length and length < 14):
                return CheckResult.PASSED
        return CheckResult.FAILED


check = PasswordPolicyLength()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.util.type_forcers import force_int


class ElasticsearchNodeToNodeEncryption(BaseResourceCheck):
    def __init__(self):
        name = "Ensure all Elasticsearch has node-to-node encryption enabled"
        id = "CKV_AWS_6"
        supported_resources = ['aws_elasticsearch_domain', 'aws_opensearch_domain']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for node to node encryption configuration at aws_elasticsearch_domain:
            https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html
            and https://registry.terraform.io/providers/hashicorp/aws/latest/docs/resources/opensearch_domain
        :param conf: aws_elasticsearch_domain configuration
        :return: <CheckResult>
        """
        self.evaluated_keys = ['cluster_config']
        cluster_config = conf.get("cluster_config")
        if not cluster_config or not isinstance(cluster_config[0], dict):
            return CheckResult.PASSED
        if "instance_count" not in cluster_config[0]:
            return CheckResult.PASSED

        self.evaluated_keys = ['cluster_config/[0]/instance_count']
        instance_count = cluster_config[0]["instance_count"]
        if isinstance(instance_count, list):
            instance_count = instance_count[0]
            if not isinstance(instance_count, int):
                return CheckResult.UNKNOWN
        if not instance_count:
            return CheckResult.UNKNOWN
        if instance_count <= 1:
            return CheckResult.PASSED

        self.evaluated_keys.append('node_to_node_encryption/[0]/enabled')
        if "node_to_node_encryption" in conf.keys() and "enabled" in conf["node_to_node_encryption"][0]:
            n2n_enc_enabled = conf["node_to_node_encryption"][0]["enabled"]
            if isinstance(n2n_enc_enabled, list):
                n2n_enc_enabled = conf["node_to_node_encryption"][0]["enabled"][0]
            if not isinstance(n2n_enc_enabled, bool):
                return CheckResult.UNKNOWN
            if n2n_enc_enabled:
                return CheckResult.PASSED
        return CheckResult.FAILED


check = ElasticsearchNodeToNodeEncryption()



from checkov.common.models.consts import ANY_VALUE
from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class AzureManagedDiskEncryptionSet(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that managed disks use a specific set of disk encryption sets for the " \
               "customer-managed key encryption"
        id = "CKV_AZURE_93"
        supported_resources = ['azurerm_managed_disk']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'disk_encryption_set_id'

    def get_expected_value(self):
        return ANY_VALUE


check = AzureManagedDiskEncryptionSet()



from typing import Any

from checkov.cloudformation.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.consts import ANY_VALUE
from checkov.common.models.enums import CheckCategories


class S3AccessLogs(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure the S3 bucket has access logging enabled"
        id = "CKV_AWS_18"
        supported_resources = ['AWS::S3::Bucket']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "Properties/LoggingConfiguration"

    def get_expected_value(self) -> Any:
        return ANY_VALUE


check = S3AccessLogs()



from checkov.common.models.enums import CheckCategories,CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class RDSRetention(BaseResourceCheck):
    def __init__(self):

        """
        'sql_collector_status' should be defined and set to "Enabled"  (I know, really, who does that)
         and 'sql_collector_config_value' should be defined and set to 180 or more
        """
        name = "Ensure RDS Instance SQL Collector Retention Period should be greater than 180"
        id = "CKV_ALI_25"
        supported_resources = ['alicloud_db_instance']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf) -> CheckResult:
        if conf.get("sql_collector_status") and isinstance(conf.get("sql_collector_status"), list):
            status = conf.get("sql_collector_status")[0]
            if status != "Enabled":
                self.evaluated_keys = ["sql_collector_status"]
                return CheckResult.FAILED
            if conf.get("sql_collector_config_value") and isinstance(conf.get("sql_collector_config_value"), list):
                self.evaluated_keys = ["sql_collector_config_value"]
                config = conf.get("sql_collector_config_value")[0]
                if config >= 180:
                    return CheckResult.PASSED

        return CheckResult.FAILED

check = RDSRetention()



from checkov.common.output.report import CheckType
from checkov.gitlab.dal import Gitlab
from checkov.json_doc.runner import Runner as JsonRunner
from checkov.runner_filter import RunnerFilter


class Runner(JsonRunner):
    check_type = CheckType.GITLAB_CONFIGURATION

    def __init__(self):
        self.gitlab = Gitlab()
        super().__init__()

    def run(self, root_folder=None, external_checks_dir=None, files=None,
            runner_filter=RunnerFilter(), collect_skip_comments=True):
        self.prepare_data()

        report = super().run(root_folder=self.gitlab.gitlab_conf_dir_path, external_checks_dir=external_checks_dir,
                             files=files,
                             runner_filter=runner_filter, collect_skip_comments=collect_skip_comments)
        JsonRunner._change_files_path_to_relative(report)
        return report

    def prepare_data(self):
        self.gitlab.persist_all_confs()

    def require_external_checks(self):
        # default json runner require only external checks. Gitlab runner brings build in checks
        return False

    def import_registry(self):
        from checkov.gitlab.registry import registry
        return registry



from cyclonedx.output.xml import XmlV1Dot3
from xml.etree import ElementTree  # nosec


class ExtXml(XmlV1Dot3):

    def output_as_string(self) -> str:
        bom = self._get_bom_root_element()

        if self.bom_supports_metadata():
            bom = self._add_metadata(bom=bom)

        if self.get_bom().has_vulnerabilities():
            ElementTree.register_namespace('v', XmlV1Dot3.get_vulnerabilities_namespace())

        components = ElementTree.SubElement(bom, 'components')

        for component in self.get_bom().get_components():
            component_element = self._get_component_as_xml_element(component=component)
            components.append(component_element)
            if component.has_vulnerabilities() and self.component_supports_bom_ref():
                # Vulnerabilities are only possible when bom-ref is supported by the main CycloneDX schema version
                vulnerabilities = ElementTree.SubElement(component_element, 'v:vulnerabilities')
                for vulnerability in component.get_vulnerabilities():
                    vulnerabilities.append(self._get_vulnerability_as_xml_element(bom_ref=component.get_purl() +
                                                                                          vulnerability.get_id(),
                                                                                  vulnerability=vulnerability))

        return XmlV1Dot3.XML_VERSION_DECLARATION + ElementTree.tostring(bom, 'unicode')



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class WinVMEncryptionAtHost(BaseResourceValueCheck):
    def __init__(self):
        """
        If enabled, all the disks (including the temp disk) attached to this Virtual Machine will be encrypted
        """
        name = "Ensure Windows VM enables encryption"
        id = "CKV_AZURE_151"
        supported_resources = ['azurerm_windows_virtual_machine']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "encryption_at_host_enabled"


check = WinVMEncryptionAtHost()



from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class ContainerSecurityContext(BaseResourceCheck):

    def __init__(self):
        # CIS-1.5 5.7.3
        name = "Apply security context to your pods and containers"
        # Security context can be set at pod or container level.
        # Location: container .securityContext
        id = "CKV_K8S_30"

        supported_resources = ['kubernetes_pod']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf) -> CheckResult:
        spec = conf['spec'][0]
        if spec.get("container"):
            containers = spec.get("container")

            for idx, container in enumerate(containers):
                if type(container) != dict:
                    return CheckResult.UNKNOWN
                if not container.get("security_context"):
                    self.evaluated_keys = [f'spec/[0]/container/[{idx}]/security_context']
                    return CheckResult.FAILED
        return CheckResult.PASSED


check = ContainerSecurityContext()



from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories, CheckResult


class KMSKeyIsEnabled(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure KMS key is enabled"
        id = "CKV_AWS_227"
        supported_resources = ('aws_kms_key',)
        categories = (CheckCategories.ENCRYPTION,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                         missing_block_result=CheckResult.PASSED)

    def get_inspected_key(self) -> str:
        return "is_enabled"


check = KMSKeyIsEnabled()
